@@ -13,6 +13,13 @@ import traceback
 # from albert_kmeans import *
 import pprint
 
+from  warnings import simplefilter
+
+# 忽略sk错误提示
+from sklearn.exceptions import ConvergenceWarning
+simplefilter("ignore", category=ConvergenceWarning)
+
+
 device="cpu"
 
 
@@ -63,6 +70,19 @@ def search_sent(keyword):
     s = Search(using=client, index="pet-sent-index").query(q)
     response = s.execute()
     return response
+
+def search_sent_plus(keyword):
+    client = Elasticsearch()
+    q = Q("multi_match", query=keyword, fields=['title', 'content'])
+    s = Search(using=client)
+    # s = Search(using=client, index="pet-index").query("match", content="金毛")
+    s = Search(using=client, index="pet-sent-index").query(q)
+    s=s[0:20]
+    s=s.highlight_options(order='score')
+    # 高亮显示匹配
+    s = s.highlight('content')
+    response = s.execute()
+    return response
 def find_sent(keyword):
     text=''
     for sent in search_sent(keyword):
